summaryrefslogtreecommitdiff
path: root/sys/msdk/gstmsdkh265dec.c
diff options
context:
space:
mode:
Diffstat (limited to 'sys/msdk/gstmsdkh265dec.c')
-rw-r--r--sys/msdk/gstmsdkh265dec.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/sys/msdk/gstmsdkh265dec.c b/sys/msdk/gstmsdkh265dec.c
index 7e2a77032..fe41c09f0 100644
--- a/sys/msdk/gstmsdkh265dec.c
+++ b/sys/msdk/gstmsdkh265dec.c
@@ -34,7 +34,7 @@
* @title: msdkh265dec
* @short_description: Intel MSDK H265 decoder
*
* H265 video decoder based on Intel Media SDK
*
* ## Example launch line
* ```
@@ -193,7 +193,7 @@ gst_msdkh265dec_class_init (GstMsdkH265DecClass * klass)
gst_element_class_set_static_metadata (element_class,
"Intel MSDK H265 decoder",
"Codec/Decoder/Video/Hardware",
- "H265 video decoder based on Intel Media SDK",
+ "H265 video decoder based on " MFX_API_SDK,
"Scott D Phillips <scott.d.phillips@intel.com>");
gst_msdkdec_prop_install_output_oder_property (gobject_class);
@@ -34,7 +34,7 @@
* @short_description: Intel MSDK H265 decoder
*
- * H265 video decoder based on Intel Media SDK
+ * H265 video decoder based on Intel MFX
*
* ## Example launch line